==> aws-cdk-scala-glue_2.13-0.1.3-sources.jar: io/burkard/cdk/services/glue/CfnMLTransformProps.scala <==
package io.burkard.cdk.services.glue

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnMLTransformProps {

  def apply(
    transformEncryption: Option[software.amazon.awscdk.services.glue.CfnMLTransform.TransformEncryptionProperty] = None,
    numberOfWorkers: Option[Number] = None,
    role: Option[String] = None,
    inputRecordTables: Option[software.amazon.awscdk.services.glue.CfnMLTransform.InputRecordTablesProperty] = None,
    transformParameters: Option[software.amazon.awscdk.services.glue.CfnMLTransform.TransformParametersProperty] = None,
    timeout: Option[Number] = None,
    glueVersion: Option[String] = None,
    name: Option[String] = None,
    maxCapacity: Option[Number] = None,
    description: Option[String] = None,
    tags: Option[AnyRef] = None,
    workerType: Option[String] = None,
    maxRetries: Option[Number] = None
  ): software.amazon.awscdk.services.glue.CfnMLTransformProps =
    (new software.amazon.awscdk.services.glue.CfnMLTransformProps.Builder)
      .transformEncryption(transformEncryption.orNull)
      .numberOfWorkers(numberOfWorkers.orNull)
      .role(role.orNull)
      .inputRecordTables(inputRecordTables.orNull)
      .transformParameters(transformParameters.orNull)
      .timeout(timeout.orNull)
      .glueVersion(glueVersion.orNull)
      .name(name.orNull)
      .maxCapacity(maxCapacity.orNull)
      .description(description.orNull)
      .tags(tags.orNull)
      .workerType(workerType.orNull)
      .maxRetries(maxRetries.orNull)
      .build()
}

==> aws-cdk-scala-glue_3-0.1.5-sources.jar: io/burkard/cdk/services/glue/CfnMLTransformProps.scala <==
package io.burkard.cdk.services.glue

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnMLTransformProps {

  def apply(
    role: String,
    inputRecordTables: software.amazon.awscdk.services.glue.CfnMLTransform.InputRecordTablesProperty,
    transformParameters: software.amazon.awscdk.services.glue.CfnMLTransform.TransformParametersProperty,
    transformEncryption: Option[software.amazon.awscdk.services.glue.CfnMLTransform.TransformEncryptionProperty] = None,
    numberOfWorkers: Option[Number] = None,
    timeout: Option[Number] = None,
    glueVersion: Option[String] = None,
    name: Option[String] = None,
    maxCapacity: Option[Number] = None,
    description: Option[String] = None,
    tags: Option[AnyRef] = None,
    workerType: Option[String] = None,
    maxRetries: Option[Number] = None
  ): software.amazon.awscdk.services.glue.CfnMLTransformProps =
    (new software.amazon.awscdk.services.glue.CfnMLTransformProps.Builder)
      .role(role)
      .inputRecordTables(inputRecordTables)
      .transformParameters(transformParameters)
      .transformEncryption(transformEncryption.orNull)
      .numberOfWorkers(numberOfWorkers.orNull)
      .timeout(timeout.orNull)
      .glueVersion(glueVersion.orNull)
      .name(name.orNull)
      .maxCapacity(maxCapacity.orNull)
      .description(description.orNull)
      .tags(tags.orNull)
      .workerType(workerType.orNull)
      .maxRetries(maxRetries.orNull)
      .build()
}
